==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_entities/location_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.location_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.location_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.location_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link LocationParentHierarchy }
     * 
     */
    public LocationParentHierarchy createLocationParentHierarchy() {
        return new LocationParentHierarchy();
    }

    /**
     * Create an instance of {@link ParentLocation }
     * 
     */
    public ParentLocation createParentLocation() {
        return new ParentLocation();
    }

    /**
     * Create an instance of {@link LocationChildHierarchy }
     * 
     */
    public LocationChildHierarchy createLocationChildHierarchy() {
        return new LocationChildHierarchy();
    }

    /**
     * Create an instance of {@link ChildLocation }
     * 
     */
    public ChildLocation createChildLocation() {
        return new ChildLocation();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

    /**
     * Create an instance of {@link Location }
     * 
     */
    public Location createLocation() {
        return new Location();
    }

    /**
     * Create an instance of {@link CallCenterDetails }
     * 
     */
    public CallCenterDetails createCallCenterDetails() {
        return new CallCenterDetails();
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/location_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.location_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.location_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.location_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link LocationParentHierarchy }
     * 
     * @return
     *     the new instance of {@link LocationParentHierarchy }
     */
    public LocationParentHierarchy createLocationParentHierarchy() {
        return new LocationParentHierarchy();
    }

    /**
     * Create an instance of {@link ParentLocation }
     * 
     * @return
     *     the new instance of {@link ParentLocation }
     */
    public ParentLocation createParentLocation() {
        return new ParentLocation();
    }

    /**
     * Create an instance of {@link Location }
     * 
     * @return
     *     the new instance of {@link Location }
     */
    public Location createLocation() {
        return new Location();
    }

    /**
     * Create an instance of {@link CallCenterDetails }
     * 
     * @return
     *     the new instance of {@link CallCenterDetails }
     */
    public CallCenterDetails createCallCenterDetails() {
        return new CallCenterDetails();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     * @return
     *     the new instance of {@link UserDefinedFields }
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

    /**
     * Create an instance of {@link LocationChildHierarchy }
     * 
     * @return
     *     the new instance of {@link LocationChildHierarchy }
     */
    public LocationChildHierarchy createLocationChildHierarchy() {
        return new LocationChildHierarchy();
    }

    /**
     * Create an instance of {@link ChildLocation }
     * 
     * @return
     *     the new instance of {@link ChildLocation }
     */
    public ChildLocation createChildLocation() {
        return new ChildLocation();
    }

}
